class PcAnimationSteps extends React.Component
{
  constructor(props)
  {
    super(props);

    this.state = {currentStep:props.steps};

    this.circles = [];
    this.rectangles = [];

    this.circleRef = [];
    this.rectangleRef = [];

    for (var i=0; i<this.props.steps; i++)
    {
      this.circleRef[i] = React.createRef();
    }

    for (var i=0; i<this.props.steps-1; i++)
    {
      this.rectangleRef[i] = React.createRef();
    }
  }

  nextStep()
  {
    var index = this.props.steps - this.state.currentStep;
    if (this.rectangleRef[index]) this.rectangleRef[index].current.style.display = "block";
    if (this.circleRef[index]) this.circleRef[index].current.style.display = "block";
    this.state.currentStep--;
  }

  reset()
  {
    this.state.currentStep = this.props.steps;
    this.rectangleRef.map(item => {item.current.style.display="none"});
    this.circleRef.map(item => {item.current.style.display="none"});
  }

  setup()
  {
    var circleSize = 125*PcConfig.renderSize;
    var steps = this.props.steps;
    var refx = -(0.75*circleSize*steps - 0.25*circleSize);
    var refy = -(0.5*circleSize);

    for (var i = 0; i < steps; i++)
    {
      let circle = {index:0, x:"", y:"", width:"", height:""};
      this.circles.push(circle);
      this.circles[i].index = i;
      this.circles[i].x = refx + i*1.5*circleSize;
      this.circles[i].y = refy;
      this.circles[i].width = circleSize;
      this.circles[i].height = circleSize;

      if ((steps-i-1)>0)
      {
        let rectangle = {index:0, x:"", y:"", width:"", height:""};
        this.rectangles.push(rectangle);
        this.rectangles[i].index = i;
        this.rectangles[i].x = this.circles[i].x + 0.95*circleSize;
        this.rectangles[i].y = -circleSize/10;
        this.rectangles[i].width = circleSize/2 + 0.1*circleSize;
        this.rectangles[i].height = circleSize/5;
      }

    }
  }

  render()
  {
    this.setup();

    const bgcircles = this.circles.map(item => {
      if (item.x)
      {
        return e('div',
        {
          style:
          {
            position:"absolute",
            backgroundColor:this.props.color,
            borderRadius:"50%",
            top:item.y,
            left:item.x,
            width:item.width,
            height:item.height,
          },
          key:"bgcircle" + item.index
        }
      );
    }
    });

    const bgrectangles = this.rectangles.map(item => {
      if (item.x)
      {
        return e('div',
          {
            style:
            {
              position:"absolute",
              backgroundColor:this.props.color,
              top:item.y,
              left:item.x,
              width: item.width,
              height:item.height,
            },
            key:"bgrectangle" + item.index + "x"
          }
        );
      }
    });

    const circles = this.circles.map(item => {
      if (item.x)
      {
        return e('div',
        {
          ref:this.circleRef[item.index],
          style:
          {
            display:"none",
            position:"absolute",
            backgroundColor:this.props.color,
            borderRadius:"50%",
            top:item.y,
            left:item.x,
            width:item.width,
            height:item.height,
          },
          key:"circle" + item.index
        }
      );
    }
    });

    const rectangles = this.rectangles.map(item => {
      if (item.x)
      {
        return e('div',
          {
            ref:this.rectangleRef[item.index],
            style:
            {
              display:"none",
              position:"absolute",
              backgroundColor:this.props.color,
              top:item.y,
              left:item.x,
              width: item.width,
              height:item.height,
              animation:"rectangleXGrow " + (this.props.delay/1000) + "s linear 0s 1 forwards",
            },
            key:"rectangle" + item.index
          }
        );
      }
    });

    return e('div',
      {
        className:"pcelementshowanimation",
        style:
        {
          display: this.props.steps>1 ? "block" : "none",
          position:"absolute",
          opacity:this.props.noAnimation?1:0,
          animation:this.props.noAnimation?"":PcConfig.scenario.elementsAnimationStyle,
          animationFillMode:"forwards",
          animationDelay:this.props.showDelay,
          left:this.props.x,
          top:this.props.y
        }
      },
      e('div',
        {
          style:
          {
            position:"absolute",
            opacity:0.25
          }
        },
        bgcircles,
        bgrectangles
      ),
      circles,
      rectangles
    );
  }
}
