class PcScreenStart extends PcScreen
{
  constructor(props)
  {
    super(props);

    this.buttons = [];
    this.buttons["previous"] = React.createRef();
    this.buttons["start"] = React.createRef();

    this.registerButton(this.buttons["previous"], PcConfig.screen.start.previousButton.title);
    this.registerButton(this.buttons["start"], PcConfig.screen.start.startButton.title);
  }

  normalizeButtons()
  {
    //setTimeout(()=>{this.normalizeButtonsWidth()}, 10);
  }

  componentDidMount()
  {
        if (this.props.active) this.normalizeButtons();
  }

  componentDidUpdate()
  {
        if (this.props.active) this.normalizeButtons();
  }

  render()
  {
    if (!this.props.active) return null;

    let cameraWidth, cameraHeight, cameraTop, cameraLeft, titleY;
    let currentFormat = PcConfig.getMemory("currentFormat");
    let currentPose = PcTemplates.getTemplate(currentFormat.paper, currentFormat.poses, currentFormat.layout).poses[0];

    let poseRatio = currentPose.width/currentPose.height;

    if (PcMode.mode=="photobooth" || PcMode.mode=="cyclomaton")
    {
      if (poseRatio>1)
      {
        cameraWidth = 1000 * PcConfig.renderSize;
        cameraHeight = 1000 / poseRatio * PcConfig.renderSize;
      } else {
        cameraHeight = 720 * PcConfig.renderSize;
        cameraWidth = 720 * poseRatio * PcConfig.renderSize;
      }

      cameraTop = (this.props.height-cameraHeight)/2;
      cameraLeft = (this.props.width-cameraWidth)/2;
      titleY = this.props.height*(0.03);
    }
    else if (PcMode.mode == "photokiosk")
    {
      if (poseRatio>1)
      {
        cameraWidth = 1080 * PcConfig.renderSize;
        cameraHeight = 1080 / poseRatio * PcConfig.renderSize;
      } else {
        cameraHeight = 720 * PcConfig.renderSize;
        cameraWidth = 720 * poseRatio * PcConfig.renderSize;
      }
      cameraTop = 0;
      cameraLeft = (this.props.width-cameraWidth)/2;
      titleY = cameraTop + cameraHeight;
    }

    let buttonPrevious;

    if (PcConfig.screen.format.formats.length>1)
    {
      buttonPrevious = e(PcButton,
        {
          ref:this.buttons["previous"],
          label:PcConfig.screen.start.previousButton.title,
          fontColor:PcConfig.screen.start.previousButton.fontColor,
          borderColor:PcConfig.screen.start.previousButton.borderColor,
          backgroundColor:PcConfig.screen.start.previousButton.backgroundColor,
          prevArrow:(PcMode.mode=="photobooth" || PcMode.mode=="cyclomaton"),
          onClick:this.props.goPrevScreen,
          sound : PcConfig.sounds.buttonPrevious,
          showDelay:"0.3s"
        }
      );
    }
    else {
      buttonPrevious = null;
    }

    let buttonStart;

    if (PcMode.mode=="photobooth" || PcMode.mode=="cyclomaton")
    {
      buttonStart = e('div',
        {
          style:
            {
              position:"absolute",
              width:"50%",
              height:"12%",
              top:"85.3%",
              left:"25%",
              display:"inline-flex",
              justifyContent: "center",
              alignItems: "flex-end",
            }
        },
        e(PcButton,
          {
            ref:this.buttons["start"],
            label:"STARTTOOTO",
            fontColor:PcConfig.screen.start.startButton.fontColor,
            borderColor:PcConfig.screen.start.startButton.borderColor,
            backgroundColor:PcConfig.screen.start.startButton.backgroundColor,
            animated:true,
            onClick:this.props.goNextScreen,
            padHorizontal: 100,
            padVertical: 100,
            start:true,
            sound : PcConfig.sounds.buttonStart,
            showDelay:"0.4s"
          }
        )
      );
    }
    else if (PcMode.mode == "photokiosk")
    {
      let buttonSize = PcConfig.renderSize*580
      let py1 = cameraTop + cameraHeight + this.props.height*(0.1);
      let py = py1 + (this.props.height*0.9-py1-buttonSize)/2;

      buttonStart = e(PcRoundButton,
          {
            ref:this.buttons["start"],
            label:PcConfig.screen.start.startButton.title,
            width:buttonSize,
            height:buttonSize,
            x: (this.props.width - buttonSize)/2,
            y: py,
            fontColor:PcConfig.screen.start.startButton.fontColor,
            borderColor:PcConfig.screen.start.startButton.borderColor,
            backgroundColor:PcConfig.screen.start.startButton.backgroundColor,
            animated:true,
            onClick:this.props.goNextScreen,
            padHorizontal: 100,
            padVertical: 100,
            start:true,
            sound : PcConfig.sounds.buttonStart,
            showDelay:"0.4s"
          }
        );
    }

    return e('div',
      {
        className:this.state.className,
        index:this.props.index,
        style:
        {
          display: (this.props.active ? 'block' : 'none'),
          fontFamily:PcConfig.scenario.fontFamily,
          animation:this.props.noAnimation?"":this.state.animationStyle
        },
      },
      e(PcLabel,
        {
          label:PcConfig.screen.start.title,
          title:true,
          width:this.props.width,
          height:this.props.height*(0.1),
          x:0,
          y:titleY,
          fontSize:PcConfig.scenario.fontSizeBig,
          color: PcConfig.scenario.fontColor,
          showDelay:"0,1s"
        }
      ),
      e(PcCamera,
        {
          width:cameraWidth,
          height:cameraHeight,
          x:cameraLeft,
          y:cameraTop,
          animation:PcConfig.scenario.elementsAnimationStyle,
          showDelay:"1s",
          active:this.props.active,
          oval:false,
          foreground:currentFormat.foreground,
        }
      ),
      e('div',
        {
          style:
            {
              position:"absolute",
              width:"40%",
              height:"12%",
              top:this.props.height * PcMode.screen.start.buttonPreviousY,
              left:this.props.width * PcMode.screen.start.buttonPreviousX,
              display:"inline-flex",
              justifyContent: PcMode.screen.start.buttonPreviousJustify,
              alignItems: "flex-end",
            }
        },
        buttonPrevious
      ),
      buttonStart
    );
  }
}
